pub(crate) const fn rem_limb_with_reciprocal<const L: usize>(
u: &Uint<L>,
reciprocal: &Reciprocal,
) -> LimbExpand description
Divides u by the divisor encoded in the reciprocal, and returns the remainder.
pub(crate) const fn rem_limb_with_reciprocal<const L: usize>(
u: &Uint<L>,
reciprocal: &Reciprocal,
) -> LimbDivides u by the divisor encoded in the reciprocal, and returns the remainder.